==> huaweicloudsdkcfw-3.1.124-py2.py3-none-any.whl: huaweicloudsdkcfw/v1/model/service_item_ids.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ServiceItemIds:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'items': 'list[ServiceItemIdsItems]'
    }

    attribute_map = {
        'items': 'items'
    }

    def __init__(self, items=None):
        """ServiceItemIds

        The model defined in huaweicloud sdk

        :param items: 服务组成员id列表
        :type items: list[:class:`huaweicloudsdkcfw.v1.ServiceItemIdsItems`]
        """
        
        

        self._items = None
        self.discriminator = None

        if items is not None:
            self.items = items

    @property
    def items(self):
        """Gets the items of this ServiceItemIds.

        服务组成员id列表

        :return: The items of this ServiceItemIds.
        :rtype: list[:class:`huaweicloudsdkcfw.v1.ServiceItemIdsItems`]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this ServiceItemIds.

        服务组成员id列表

        :param items: The items of this ServiceItemIds.
        :type items: list[:class:`huaweicloudsdkcfw.v1.ServiceItemIdsItems`]
        """
        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServiceItemIds):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcfw-3.1.149-py2.py3-none-any.whl: huaweicloudsdkcfw/v1/model/service_item_ids.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ServiceItemIds:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'items': 'list[ServiceItemIdsItems]'
    }

    attribute_map = {
        'items': 'items'
    }

    def __init__(self, items=None):
        r"""ServiceItemIds

        The model defined in huaweicloud sdk

        :param items: 服务组成员id列表
        :type items: list[:class:`huaweicloudsdkcfw.v1.ServiceItemIdsItems`]
        """
        
        

        self._items = None
        self.discriminator = None

        if items is not None:
            self.items = items

    @property
    def items(self):
        r"""Gets the items of this ServiceItemIds.

        服务组成员id列表

        :return: The items of this ServiceItemIds.
        :rtype: list[:class:`huaweicloudsdkcfw.v1.ServiceItemIdsItems`]
        """
        return self._items

    @items.setter
    def items(self, items):
        r"""Sets the items of this ServiceItemIds.

        服务组成员id列表

        :param items: The items of this ServiceItemIds.
        :type items: list[:class:`huaweicloudsdkcfw.v1.ServiceItemIdsItems`]
        """
        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServiceItemIds):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
